/**
 * Utility for generating hierarchical CLAUDE.md files
 * Extracted for reusability and better testing
 */
interface TemplateFile {
    path: string;
    content: string;
}
/**
 * Check if a file exists
 * More robust than the previous inline implementation
 */
export declare function fileExists(path: string): Promise<boolean>;
/**
 * Generate multiple files with automatic directory creation
 * Skips files that already exist to avoid overwriting
 */
export declare function generateTemplateFiles(templates: TemplateFile[], options?: {
    overwrite?: boolean;
}): Promise<void>;
/**
 * Generate files with error handling and reporting
 * Returns information about what was actually created
 */
export declare function generateTemplateFilesWithReport(templates: TemplateFile[], options?: {
    overwrite?: boolean;
}): Promise<{
    created: string[];
    skipped: string[];
    errors: Array<{
        path: string;
        error: string;
    }>;
}>;
export {};
