/**
 * Constants for project analysis
 */
export declare const IGNORE_DIRECTORIES: readonly ["node_modules", ".git", ".svn", ".hg", "dist", "build", "coverage", ".nyc_output", ".next", "__pycache__", ".pytest_cache", "vendor", ".venv", "venv", "env", ".env", ".idea", ".vscode", ".DS_Store"];
export declare const SOURCE_DIRECTORIES: readonly ["src", "lib", "app", "source"];
export declare const TEST_DIRECTORIES: readonly ["test", "tests", "spec", "specs", "__tests__"];
export declare const BUILD_DIRECTORIES: readonly ["dist", "build", "out", "public", "target"];
export declare const CONFIG_DIRECTORIES: readonly ["config", "configs", ".config"];
export declare const DOCS_DIRECTORIES: readonly ["docs", "doc", "documentation"];
export declare const ESLINT_CONFIG_FILES: readonly [".eslintrc.js", ".eslintrc.json", ".eslintrc.yml", ".eslintrc.yaml", ".eslintrc"];
export declare const PRETTIER_CONFIG_FILES: readonly [".prettierrc", ".prettierrc.json", ".prettierrc.js", ".prettierrc.yml", ".prettierrc.yaml", "prettier.config.js"];
export declare const CI_CONFIG_INDICATORS: readonly [".github/workflows", ".gitlab-ci.yml", "Jenkinsfile", ".circleci", "azure-pipelines.yml", ".travis.yml", "bitbucket-pipelines.yml"];
export declare const DOCKER_INDICATORS: readonly ["Dockerfile", "docker-compose.yml", "docker-compose.yaml", ".dockerignore"];
export declare const LANGUAGE_EXTENSIONS: Record<string, string>;
export declare const FRAMEWORK_INDICATORS: {
    readonly nextjs: {
        readonly files: readonly ["next.config.js", "next.config.mjs"];
        readonly packageDep: "next";
    };
    readonly django: {
        readonly files: readonly ["manage.py"];
        readonly requirementsDep: "django";
    };
    readonly flask: {
        readonly files: readonly ["app.py", "application.py"];
        readonly requirementsDep: "flask";
    };
    readonly laravel: {
        readonly files: readonly ["artisan", "bootstrap/app.php"];
        readonly composerDep: "laravel/framework";
    };
    readonly express: {
        readonly packageDep: "express";
    };
    readonly fastapi: {
        readonly requirementsDep: "fastapi";
    };
    readonly rails: {
        readonly files: readonly ["Gemfile", "config/application.rb"];
        readonly gemDep: "rails";
    };
};
export declare const DEFAULT_CACHE_DURATION: number;
export declare const CACHE_DIR = ".ait3/cache";
export declare const CACHE_FILE = "project-analysis.json";
