import type { MigrationService, ValidationResult, MigrationResult } from '../interfaces/MigrationService.js';
import type { TicketService } from '../interfaces/TicketService.js';
export declare class TicketMigrationService implements MigrationService {
    /**
     * Parse ticket filter string into array of local ticket IDs
     * Supports formats: "1,3,5", "1-10", "1,3-5"
     * Always returns local format: ["0001", "0003", "0005"]
     */
    parseTicketFilter(filter: string): string[];
    /**
     * Validate migration between two ticket services
     */
    validateMigration(from: TicketService, to: TicketService): Promise<ValidationResult>;
    /**
     * Migrate tickets from local service to GitHub service
     */
    migrateLocalToGitHub(localService: TicketService, githubService: TicketService, ticketFilter?: string[]): Promise<MigrationResult>;
    /**
     * Get the next available GitHub issue number
     */
    getNextAvailableGitHubId(githubService: TicketService): Promise<number>;
    /**
     * Extract numeric ID from ticket ID string
     */
    private extractIdNumber;
}
