/**
 * Multi-agent code review command guide template
 * Provides structured approach for comprehensive code reviews using Claude and Gemini
 */
export declare const reviewTemplate = "# Multi-Agent Code Review\n\nPerform comprehensive code reviews using multiple AI perspectives.\n\n## Review Process\n\n### Step 1: Correctness Review (Claude)\nReview the current changes for correctness:\n- Logic errors and bugs\n- Edge case handling\n- Adherence to requirements\n- Code consistency\n\n### Step 2: Performance Review (Gemini)\nSwitch to terminal and run:\n```bash\ngemini -p \"@src/ @tests/ Review these changes for performance:\n\nFocus on:\n- Algorithm efficiency\n- Database query optimization\n- Memory usage patterns\n- Potential bottlenecks\n- Async/await optimization\"\n```\n\n### Step 3: Security Review (Claude)\nReview the changes for security issues:\n- Input validation\n- Authentication/authorization\n- SQL injection risks\n- XSS vulnerabilities\n- Sensitive data exposure\n- Dependency vulnerabilities\n\n### Step 4: Synthesize Results\nCreate a summary that includes:\n1. Critical issues from all reviews\n2. Conflicting recommendations (if any)\n3. Priority-ordered action items\n4. Overall assessment\n\n### Step 5: Document Decision\nAfter human review, document the decision:\n```bash\ngit add .\ngit commit -m \"review(#TICKET): implement review feedback\n\nCorrectness: [summary of fixes]\nPerformance: [optimizations made]\nSecurity: [vulnerabilities addressed]\n\nHuman decision: [rationale for choices made]\"\n```\n\n## Quick Commands\n\nFor specific review types:\n```bash\n# Performance only\ngemini -p \"@src/ Review this code for performance bottlenecks\"\n\n# Security only  \n# In Claude: \"Review this code for security vulnerabilities\"\n\n# Architecture review\ngemini -p \"@src/ @docs/ Is this architecture scalable and maintainable?\"\n```\n\n## Tips\n- Run reviews after GREEN phase, before REFACTOR\n- Document conflicting opinions in commit messages\n- Keep context focused on specific changes\n- Use ticket scope to limit review scope\n";
